# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.organizations_api import OrganizationsApi


class TestOrganizationsApi(unittest.IsolatedAsyncioTestCase):
    """OrganizationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OrganizationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_organization_organizations_post(self) -> None:
        """Test case for create_organization_organizations_post

        Create Organization
        """
        pass

    async def test_delete_organization_organizations_organization_id_delete(self) -> None:
        """Test case for delete_organization_organizations_organization_id_delete

        Delete Organization
        """
        pass

    async def test_get_organization_by_inn_organizations_by_inn_inn_get(self) -> None:
        """Test case for get_organization_by_inn_organizations_by_inn_inn_get

        Get Organization By Inn
        """
        pass

    async def test_get_organization_organizations_organization_id_get(self) -> None:
        """Test case for get_organization_organizations_organization_id_get

        Get Organization
        """
        pass

    async def test_list_organizations_organizations_get(self) -> None:
        """Test case for list_organizations_organizations_get

        List Organizations
        """
        pass

    async def test_update_organization_organizations_organization_id_patch(self) -> None:
        """Test case for update_organization_organizations_organization_id_patch

        Update Organization
        """
        pass


if __name__ == '__main__':
    unittest.main()
