# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.11
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.insurances_api import InsurancesApi


class TestInsurancesApi(unittest.IsolatedAsyncioTestCase):
    """InsurancesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = InsurancesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_insurance_insurances_insurance_id_get(self) -> None:
        """Test case for get_insurance_insurances_insurance_id_get

        Get Insurance
        """
        pass

    async def test_list_insurances_insurances_get(self) -> None:
        """Test case for list_insurances_insurances_get

        List Insurances
        """
        pass


if __name__ == '__main__':
    unittest.main()
