# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_list_customer_email_out import ResponseDataListCustomerEmailOut

class TestResponseDataListCustomerEmailOut(unittest.TestCase):
    """ResponseDataListCustomerEmailOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataListCustomerEmailOut:
        """Test ResponseDataListCustomerEmailOut
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataListCustomerEmailOut`
        """
        model = ResponseDataListCustomerEmailOut()
        if include_optional:
            return ResponseDataListCustomerEmailOut(
                data = [
                    sromaster.models.customer_email_out.CustomerEmailOut(
                        id = 56, 
                        label = '', 
                        email = '', 
                        is_primary = True, )
                    ]
            )
        else:
            return ResponseDataListCustomerEmailOut(
                data = [
                    sromaster.models.customer_email_out.CustomerEmailOut(
                        id = 56, 
                        label = '', 
                        email = '', 
                        is_primary = True, )
                    ],
        )
        """

    def testResponseDataListCustomerEmailOut(self):
        """Test ResponseDataListCustomerEmailOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
