# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.4
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_sro_public import ResponseDataSROPublic

class TestResponseDataSROPublic(unittest.TestCase):
    """ResponseDataSROPublic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataSROPublic:
        """Test ResponseDataSROPublic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataSROPublic`
        """
        model = ResponseDataSROPublic()
        if include_optional:
            return ResponseDataSROPublic(
                data = sromaster.models.sro_public.SROPublic(
                    id = 56, 
                    registry = 'NOPRIZ', 
                    registry_id = 56, 
                    name = '', 
                    reg_number = '', 
                    inn = 56, 
                    ogrn = 56, 
                    address = '', 
                    phone = '', 
                    email = '', 
                    website = '', 
                    members_count = 56, )
            )
        else:
            return ResponseDataSROPublic(
                data = sromaster.models.sro_public.SROPublic(
                    id = 56, 
                    registry = 'NOPRIZ', 
                    registry_id = 56, 
                    name = '', 
                    reg_number = '', 
                    inn = 56, 
                    ogrn = 56, 
                    address = '', 
                    phone = '', 
                    email = '', 
                    website = '', 
                    members_count = 56, ),
        )
        """

    def testResponseDataSROPublic(self):
        """Test ResponseDataSROPublic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
