# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from sromaster.models.tariff_entry import TariffEntry
from typing import Optional, Set
from typing_extensions import Self

class IMSroUpsertRequest(BaseModel):
    """
    IMSroUpsertRequest
    """ # noqa: E501
    tariffs: Optional[Dict[str, TariffEntry]] = None
    description: Optional[StrictStr] = None
    pre_expiry_days: Optional[Annotated[int, Field(le=3650, strict=True, ge=0)]] = None
    insurance_regulations: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["tariffs", "description", "pre_expiry_days", "insurance_regulations"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IMSroUpsertRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in tariffs (dict)
        _field_dict = {}
        if self.tariffs:
            for _key_tariffs in self.tariffs:
                if self.tariffs[_key_tariffs]:
                    _field_dict[_key_tariffs] = self.tariffs[_key_tariffs].to_dict()
            _dict['tariffs'] = _field_dict
        # set to None if tariffs (nullable) is None
        # and model_fields_set contains the field
        if self.tariffs is None and "tariffs" in self.model_fields_set:
            _dict['tariffs'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if pre_expiry_days (nullable) is None
        # and model_fields_set contains the field
        if self.pre_expiry_days is None and "pre_expiry_days" in self.model_fields_set:
            _dict['pre_expiry_days'] = None

        # set to None if insurance_regulations (nullable) is None
        # and model_fields_set contains the field
        if self.insurance_regulations is None and "insurance_regulations" in self.model_fields_set:
            _dict['insurance_regulations'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IMSroUpsertRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "tariffs": dict(
                (_k, TariffEntry.from_dict(_v))
                for _k, _v in obj["tariffs"].items()
            )
            if obj.get("tariffs") is not None
            else None,
            "description": obj.get("description"),
            "pre_expiry_days": obj.get("pre_expiry_days"),
            "insurance_regulations": obj.get("insurance_regulations")
        })
        return _obj


