# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.2
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.check_type import CheckType

class TestCheckType(unittest.TestCase):
    """CheckType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCheckType(self):
        """Test CheckType"""
        # inst = CheckType()

if __name__ == '__main__':
    unittest.main()
