# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.src_models_sro_member_registry import SrcModelsSroMemberRegistry

class TestSrcModelsSroMemberRegistry(unittest.TestCase):
    """SrcModelsSroMemberRegistry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSrcModelsSroMemberRegistry(self):
        """Test SrcModelsSroMemberRegistry"""
        # inst = SrcModelsSroMemberRegistry()

if __name__ == '__main__':
    unittest.main()
