# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.im_insurers_api import ImInsurersApi


class TestImInsurersApi(unittest.IsolatedAsyncioTestCase):
    """ImInsurersApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ImInsurersApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_im_insurer_im_insurers_post(self) -> None:
        """Test case for create_im_insurer_im_insurers_post

        Create Im Insurer
        """
        pass

    async def test_delete_im_insurer_im_insurers_insurer_id_delete(self) -> None:
        """Test case for delete_im_insurer_im_insurers_insurer_id_delete

        Delete Im Insurer
        """
        pass

    async def test_get_im_insurer_im_insurers_insurer_id_get(self) -> None:
        """Test case for get_im_insurer_im_insurers_insurer_id_get

        Get Im Insurer
        """
        pass

    async def test_list_im_insurers_im_insurers_get(self) -> None:
        """Test case for list_im_insurers_im_insurers_get

        List Im Insurers
        """
        pass

    async def test_update_im_insurer_im_insurers_insurer_id_patch(self) -> None:
        """Test case for update_im_insurer_im_insurers_insurer_id_patch

        Update Im Insurer
        """
        pass


if __name__ == '__main__':
    unittest.main()
