# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.page_im_sro_public_output import PageIMSroPublicOutput

class TestPageIMSroPublicOutput(unittest.TestCase):
    """PageIMSroPublicOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageIMSroPublicOutput:
        """Test PageIMSroPublicOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageIMSroPublicOutput`
        """
        model = PageIMSroPublicOutput()
        if include_optional:
            return PageIMSroPublicOutput(
                items = [
                    sromaster.models.im_sro_public.IMSroPublic(
                        sro_id = 56, 
                        tariffs = {
                            'key' : { }
                            }, 
                        description = '', 
                        pre_expiry_days = 56, )
                    ],
                page = 56,
                per_page = 56,
                total = 56,
                total_pages = 56
            )
        else:
            return PageIMSroPublicOutput(
                items = [
                    sromaster.models.im_sro_public.IMSroPublic(
                        sro_id = 56, 
                        tariffs = {
                            'key' : { }
                            }, 
                        description = '', 
                        pre_expiry_days = 56, )
                    ],
                page = 56,
                per_page = 56,
                total = 56,
                total_pages = 56,
        )
        """

    def testPageIMSroPublicOutput(self):
        """Test PageIMSroPublicOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
