# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.customers_api import CustomersApi


class TestCustomersApi(unittest.IsolatedAsyncioTestCase):
    """CustomersApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CustomersApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_add_customer_email_customers_customer_id_emails_post(self) -> None:
        """Test case for add_customer_email_customers_customer_id_emails_post

        Add Customer Email
        """
        pass

    async def test_add_customer_phone_customers_customer_id_phones_post(self) -> None:
        """Test case for add_customer_phone_customers_customer_id_phones_post

        Add Customer Phone
        """
        pass

    async def test_create_customer_customers_post(self) -> None:
        """Test case for create_customer_customers_post

        Create Customer
        """
        pass

    async def test_delete_customer_customers_customer_id_delete(self) -> None:
        """Test case for delete_customer_customers_customer_id_delete

        Delete Customer
        """
        pass

    async def test_delete_customer_email_customers_customer_id_emails_email_id_delete(self) -> None:
        """Test case for delete_customer_email_customers_customer_id_emails_email_id_delete

        Delete Customer Email
        """
        pass

    async def test_delete_customer_phone_customers_customer_id_phones_phone_id_delete(self) -> None:
        """Test case for delete_customer_phone_customers_customer_id_phones_phone_id_delete

        Delete Customer Phone
        """
        pass

    async def test_get_customer_customers_customer_id_get(self) -> None:
        """Test case for get_customer_customers_customer_id_get

        Get Customer
        """
        pass

    async def test_list_customer_emails_customers_customer_id_emails_get(self) -> None:
        """Test case for list_customer_emails_customers_customer_id_emails_get

        List Customer Emails
        """
        pass

    async def test_list_customer_phones_customers_customer_id_phones_get(self) -> None:
        """Test case for list_customer_phones_customers_customer_id_phones_get

        List Customer Phones
        """
        pass

    async def test_list_customers_customers_get(self) -> None:
        """Test case for list_customers_customers_get

        List Customers
        """
        pass

    async def test_update_customer_customers_customer_id_patch(self) -> None:
        """Test case for update_customer_customers_customer_id_patch

        Update Customer
        """
        pass

    async def test_update_customer_email_customers_customer_id_emails_email_id_patch(self) -> None:
        """Test case for update_customer_email_customers_customer_id_emails_email_id_patch

        Update Customer Email
        """
        pass

    async def test_update_customer_phone_customers_customer_id_phones_phone_id_patch(self) -> None:
        """Test case for update_customer_phone_customers_customer_id_phones_phone_id_patch

        Update Customer Phone
        """
        pass


if __name__ == '__main__':
    unittest.main()
