# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.10
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_im_email_out import ResponseDataIMEmailOut

class TestResponseDataIMEmailOut(unittest.TestCase):
    """ResponseDataIMEmailOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataIMEmailOut:
        """Test ResponseDataIMEmailOut
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataIMEmailOut`
        """
        model = ResponseDataIMEmailOut()
        if include_optional:
            return ResponseDataIMEmailOut(
                data = sromaster.models.im_email_out.IMEmailOut(
                    id = 56, 
                    organization_id = 56, 
                    email = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return ResponseDataIMEmailOut(
                data = sromaster.models.im_email_out.IMEmailOut(
                    id = 56, 
                    organization_id = 56, 
                    email = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testResponseDataIMEmailOut(self):
        """Test ResponseDataIMEmailOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
