# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.11
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.organization_emails_api import OrganizationEmailsApi


class TestOrganizationEmailsApi(unittest.IsolatedAsyncioTestCase):
    """OrganizationEmailsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OrganizationEmailsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_org_email_organization_emails_post(self) -> None:
        """Test case for create_org_email_organization_emails_post

        Create Org Email
        """
        pass

    async def test_delete_org_email_organization_emails_item_id_delete(self) -> None:
        """Test case for delete_org_email_organization_emails_item_id_delete

        Delete Org Email
        """
        pass

    async def test_get_org_email_organization_emails_item_id_get(self) -> None:
        """Test case for get_org_email_organization_emails_item_id_get

        Get Org Email
        """
        pass

    async def test_list_org_emails_organization_emails_get(self) -> None:
        """Test case for list_org_emails_organization_emails_get

        List Org Emails
        """
        pass

    async def test_update_org_email_organization_emails_item_id_patch(self) -> None:
        """Test case for update_org_email_organization_emails_item_id_patch

        Update Org Email
        """
        pass


if __name__ == '__main__':
    unittest.main()
