# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.organization_create import OrganizationCreate

class TestOrganizationCreate(unittest.TestCase):
    """OrganizationCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationCreate:
        """Test OrganizationCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationCreate`
        """
        model = OrganizationCreate()
        if include_optional:
            return OrganizationCreate(
                source_registry = 'NOPRIZ',
                inn = '',
                ogrn = '',
                legal_form = 'LEGAL_ENTITY',
                name_full = '',
                name_short = '',
                address = '',
                director_name = '',
                registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return OrganizationCreate(
                source_registry = 'NOPRIZ',
        )
        """

    def testOrganizationCreate(self):
        """Test OrganizationCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
