# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.11
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.invoice_upload_url_request import InvoiceUploadUrlRequest

class TestInvoiceUploadUrlRequest(unittest.TestCase):
    """InvoiceUploadUrlRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoiceUploadUrlRequest:
        """Test InvoiceUploadUrlRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoiceUploadUrlRequest`
        """
        model = InvoiceUploadUrlRequest()
        if include_optional:
            return InvoiceUploadUrlRequest(
                filename = '',
                content_type = '',
                size = 0.0
            )
        else:
            return InvoiceUploadUrlRequest(
                filename = '',
                content_type = '',
        )
        """

    def testInvoiceUploadUrlRequest(self):
        """Test InvoiceUploadUrlRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
