# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LegalForm(str, Enum):
    """
    LegalForm
    """

    """
    allowed enum values
    """
    LEGAL_ENTITY = 'LEGAL_ENTITY'
    INDIVIDUAL = 'INDIVIDUAL'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LegalForm from a JSON string"""
        return cls(json.loads(json_str))


