# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_list_im_mailing_out import ResponseDataListIMMailingOut

class TestResponseDataListIMMailingOut(unittest.TestCase):
    """ResponseDataListIMMailingOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataListIMMailingOut:
        """Test ResponseDataListIMMailingOut
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataListIMMailingOut`
        """
        model = ResponseDataListIMMailingOut()
        if include_optional:
            return ResponseDataListIMMailingOut(
                data = [
                    sromaster.models.im_mailing_out.IMMailingOut(
                        id = 56, 
                        organization_id = 56, 
                        insurance_id = 56, 
                        im_insurer_id = 56, 
                        dispatch_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        email_search_status = 'PENDING', 
                        invoice_status = 'PENDING', 
                        invoice_url = '', 
                        status = 'PENDING', 
                        result = 'FAILURE', 
                        insurance_premium = '', )
                    ]
            )
        else:
            return ResponseDataListIMMailingOut(
                data = [
                    sromaster.models.im_mailing_out.IMMailingOut(
                        id = 56, 
                        organization_id = 56, 
                        insurance_id = 56, 
                        im_insurer_id = 56, 
                        dispatch_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        email_search_status = 'PENDING', 
                        invoice_status = 'PENDING', 
                        invoice_url = '', 
                        status = 'PENDING', 
                        result = 'FAILURE', 
                        insurance_premium = '', )
                    ],
        )
        """

    def testResponseDataListIMMailingOut(self):
        """Test ResponseDataListIMMailingOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
