# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.invoice_status import InvoiceStatus

class TestInvoiceStatus(unittest.TestCase):
    """InvoiceStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInvoiceStatus(self):
        """Test InvoiceStatus"""
        # inst = InvoiceStatus()

if __name__ == '__main__':
    unittest.main()
