# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.im_mailing_api import ImMailingApi


class TestImMailingApi(unittest.IsolatedAsyncioTestCase):
    """ImMailingApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ImMailingApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_item_im_mailing_post(self) -> None:
        """Test case for create_item_im_mailing_post

        Create Item
        """
        pass

    async def test_delete_item_im_mailing_item_id_delete(self) -> None:
        """Test case for delete_item_im_mailing_item_id_delete

        Delete Item
        """
        pass

    async def test_get_item_im_mailing_item_id_get(self) -> None:
        """Test case for get_item_im_mailing_item_id_get

        Get Item
        """
        pass

    async def test_list_items_im_mailing_get(self) -> None:
        """Test case for list_items_im_mailing_get

        List Items
        """
        pass

    async def test_update_item_im_mailing_item_id_patch(self) -> None:
        """Test case for update_item_im_mailing_item_id_patch

        Update Item
        """
        pass


if __name__ == '__main__':
    unittest.main()
