# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.6
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.parser_write_api import ParserWriteApi


class TestParserWriteApi(unittest.IsolatedAsyncioTestCase):
    """ParserWriteApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ParserWriteApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_upsert_sro_members_parser_sro_members_post(self) -> None:
        """Test case for upsert_sro_members_parser_sro_members_post

        Upsert Sro Members
        """
        pass

    async def test_upsert_sro_parser_sros_post(self) -> None:
        """Test case for upsert_sro_parser_sros_post

        Upsert Sro
        """
        pass


if __name__ == '__main__':
    unittest.main()
