# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_page_organization_out import ResponseDataPageOrganizationOut

class TestResponseDataPageOrganizationOut(unittest.TestCase):
    """ResponseDataPageOrganizationOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataPageOrganizationOut:
        """Test ResponseDataPageOrganizationOut
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataPageOrganizationOut`
        """
        model = ResponseDataPageOrganizationOut()
        if include_optional:
            return ResponseDataPageOrganizationOut(
                data = sromaster.models.page[organization_out].Page[OrganizationOut](
                    items = [
                        sromaster.models.organization_out.OrganizationOut(
                            id = 56, 
                            source_registry = 'NOPRIZ', 
                            inn = '', 
                            ogrn = '', 
                            legal_form = 'LEGAL_ENTITY', 
                            name_full = '', 
                            name_short = '', 
                            address = '', 
                            director_name = '', 
                            registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    page = 56, 
                    per_page = 56, 
                    total = 56, 
                    total_pages = 56, )
            )
        else:
            return ResponseDataPageOrganizationOut(
                data = sromaster.models.page[organization_out].Page[OrganizationOut](
                    items = [
                        sromaster.models.organization_out.OrganizationOut(
                            id = 56, 
                            source_registry = 'NOPRIZ', 
                            inn = '', 
                            ogrn = '', 
                            legal_form = 'LEGAL_ENTITY', 
                            name_full = '', 
                            name_short = '', 
                            address = '', 
                            director_name = '', 
                            registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    page = 56, 
                    per_page = 56, 
                    total = 56, 
                    total_pages = 56, ),
        )
        """

    def testResponseDataPageOrganizationOut(self):
        """Test ResponseDataPageOrganizationOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
