# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.11
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.im_mailing_invoices_api import ImMailingInvoicesApi


class TestImMailingInvoicesApi(unittest.IsolatedAsyncioTestCase):
    """ImMailingInvoicesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ImMailingInvoicesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_delete_invoice_im_mailing_item_id_invoices_invoice_id_delete(self) -> None:
        """Test case for delete_invoice_im_mailing_item_id_invoices_invoice_id_delete

        Delete Invoice
        """
        pass

    async def test_finalize_invoice_im_mailing_item_id_invoices_post(self) -> None:
        """Test case for finalize_invoice_im_mailing_item_id_invoices_post

        Finalize Invoice
        """
        pass

    async def test_get_invoice_download_url_im_mailing_item_id_invoices_invoice_id_download_url_get(self) -> None:
        """Test case for get_invoice_download_url_im_mailing_item_id_invoices_invoice_id_download_url_get

        Get Invoice Download Url
        """
        pass

    async def test_get_invoice_im_mailing_item_id_invoices_invoice_id_get(self) -> None:
        """Test case for get_invoice_im_mailing_item_id_invoices_invoice_id_get

        Get Invoice
        """
        pass

    async def test_list_invoices_im_mailing_item_id_invoices_get(self) -> None:
        """Test case for list_invoices_im_mailing_item_id_invoices_get

        List Invoices
        """
        pass

    async def test_request_upload_url_im_mailing_item_id_invoices_upload_url_post(self) -> None:
        """Test case for request_upload_url_im_mailing_item_id_invoices_upload_url_post

        Request Upload Url
        """
        pass


if __name__ == '__main__':
    unittest.main()
